<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

if ( ! function_exists( 'boost_biz_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Boost Biz Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function boost_biz_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'boost_biz_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'boost_biz_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Boost Biz Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function boost_biz_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'boost_biz_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'boost_biz_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Boost Biz Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function boost_biz_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'boost_biz_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[topbar_section_enable]' )->value() );
}


/**
 * Check if login_register_meta section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_login_register_meta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[contact_button_login_register_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_slider_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if( $control->id == 'boost_biz_pro_slider_section' ) {
		return ($home_layout != 'second-design');
	}
	
	if( ($home_layout == 'third-design') && (in_array($control->id,array('boost_biz_pro_theme_options[slider_section_social_nav_enable]','boost_biz_pro_theme_options[slider_alt_btn_label]','boost_biz_pro_theme_options[slider_alt_btn_url]'))) ) return false;
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[slider_content_type]' )->value();
	return boost_biz_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[slider_content_type]' )->value();
	return boost_biz_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[slider_content_type]' )->value();
	return boost_biz_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if introduction section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_introduction_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if( $control->id == 'boost_biz_pro_introduction_section') {
		return ($home_layout == 'second-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[introduction_section_enable]' )->value() );
}

/**
 * Check if introduction section content type is custom.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_introduction_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[introduction_content_type]' )->value();
	return boost_biz_pro_is_introduction_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if introduction section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_introduction_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[introduction_content_type]' )->value();
	return boost_biz_pro_is_introduction_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if introduction section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_introduction_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[introduction_content_type]' )->value();
	return boost_biz_pro_is_introduction_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_about_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_about_section') {
		return ($home_layout != 'second-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is custom.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[about_content_type]' )->value();
	return boost_biz_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[about_content_type]' )->value();
	return boost_biz_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[about_content_type]' )->value();
	return boost_biz_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_service_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_service_section'){
		return ($home_layout != 'second-design');
	}

	if($home_layout == 'third-design' && in_array($control->id, array(
		'boost_biz_pro_theme_options[service_btn_title]',
		'boost_biz_pro_theme_options[service_link]',
		'boost_biz_pro_theme_options[service_sub_title]'
		))) return false;

	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[service_content_type]' )->value();
	return boost_biz_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[service_content_type]' )->value();
	return boost_biz_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[service_content_type]' )->value();
	return boost_biz_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[service_content_type]' )->value();
	return boost_biz_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section image type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_service_section_image_enable( $control ) {
	$image_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[service_image_type]' )->value();
	return boost_biz_pro_is_service_section_enable( $control ) && ( 'icon' == $image_type );
}

/**
 * Check if portfolio section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_portfolio_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_portfolio_section') {
		return ($home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[portfolio_section_enable]' )->value() );
}

/**
 * Check if portfolio section content type is category.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_portfolio_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[portfolio_content_type]' )->value();
	return boost_biz_pro_is_portfolio_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if portfolio section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_portfolio_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[portfolio_content_type]' )->value();
	return boost_biz_pro_is_portfolio_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if portfolio section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_portfolio_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[portfolio_content_type]' )->value();
	return boost_biz_pro_is_portfolio_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if interest section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_interest_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_interest_section') {
		return ($home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[interest_section_enable]' )->value() );
}

/**
 * Check if client section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_client_section') {
		return ($home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[client_section_enable]' )->value() );
}

/**
 * Check if client section content type is custom.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if client section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if client section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if client_logo section content type is custom.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_logo_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_logo_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if client_logo section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_logo_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_logo_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if client_logo section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_logo_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_logo_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if client_logo section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_client_logo_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[client_logo_content_type]' )->value();
	return boost_biz_pro_is_client_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_blog_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($home_layout == 'second-design' && in_array($control->id, array(
		'boost_biz_pro_theme_options[blog_title]',
		'boost_biz_pro_theme_options[blog_sub_title]',
		'boost_biz_pro_theme_options[blog_btn_url]',
		'boost_biz_pro_theme_options[blog_btn_title]'
		))) return false;

	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[blog_content_type]' )->value();
	return boost_biz_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[blog_content_type]' )->value();
	return boost_biz_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[blog_content_type]' )->value();
	return boost_biz_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[blog_content_type]' )->value();
	return boost_biz_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_cta_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_cta_section') {
		return ($home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[cta_content_type]' )->value();
	return boost_biz_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[cta_content_type]' )->value();
	return boost_biz_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[cta_content_type]' )->value();
	return boost_biz_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_testimonial_section') {
		return ($home_layout != 'second-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_content_type]' )->value();
	return boost_biz_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_content_type]' )->value();
	return boost_biz_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_content_type]' )->value();
	return boost_biz_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_content_type]' )->value();
	return boost_biz_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_content_type]' )->value();
	return boost_biz_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[testimonial_content_type]' )->value();
	return boost_biz_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_team_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_team_section') {
		return ($home_layout == 'third-design' || $home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section seperator.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[team_content_type]' )->value();
	return boost_biz_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[team_content_type]' )->value();
	return boost_biz_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[team_content_type]' )->value();
	return boost_biz_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[team_content_type]' )->value();
	return boost_biz_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is position.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_team_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'boost_biz_pro_theme_options[team_content_type]' )->value();
	return boost_biz_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
}
/**
 * Check if counter section is enabled.
 *
 * @since Boost Biz Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function boost_biz_pro_is_counter_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'boost_biz_pro_theme_options[home_layout]' )->value();
	if($control->id == 'boost_biz_pro_counter_section') {
		return ($home_layout == 'third-design' || $home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'boost_biz_pro_theme_options[counter_section_enable]' )->value() );
}