<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 * @return array An array of default values
 */

function boost_biz_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$boost_biz_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#5031a9',
		'header_tagline_color'			=> '#5a677a',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#5031a9',
		'secondary_colorscheme_hue'		=> '#f14b59',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'boost-biz-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'boost-biz-pro' ), '[the-year]', '[site-link]' ),
		'poweredby_text'           		=> esc_html__( 'All Rights Reserved | ', 'boost-biz-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'boost-biz-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'footer_menu'					=> false,
		'footer_social_menu'			=> false,
		

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,introduction,about,service,team,portfolio,interest,testimonial,client,blog,cta,counter',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'boost-biz-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> false,
		'topbar_email'					=> 'info@themepalace.com',
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'boost-biz-pro' ),


		// login button
		'contact_button_login_register_enable'	=> false,
		'contact_button_login_label'			=> esc_html__( 'Contact Us', 'boost-biz-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'page',
		'slider_autoplay_enable'		=> false,
		'slider_section_social_nav_enable'	=> true,
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Get Started', 'boost-biz-pro' ),
		'slider_alt_btn_label'			=> esc_html__( 'Browse MarketPlace', 'boost-biz-pro' ),

		// Introduction
		'introduction_section_enable'			=> true,
		'introduction_content_type'				=> 'post',
		'introduction_btn_title'				=> esc_html__( 'Learn More', 'boost-biz-pro' ),
		'introduction_sub_title'				=> esc_html__( 'Education', 'boost-biz-pro' ),
		'introduction_title'					=> esc_html__( 'Lunch or grow your business now', 'boost-biz-pro' ),


		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_count'					=> 1,
		'about_btn_title'				=> esc_html__( 'Know More About Me', 'boost-biz-pro' ),
		'about_description'				=> esc_html__( 'With the help of our profile settings. you can find your target audience and engage with them without having to do everything manally. Simply play with our filters and let our AI take care of rest.', 'boost-biz-pro' ),
		'about_sub_title'				=> esc_html__( 'About Me', 'boost-biz-pro' ),
		'about_title'					=> esc_html__( 'Lunch or grow your business now', 'boost-biz-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_column'				=> 'col-3',
		'service_sub_title'				=> esc_html__( 'Main Features', 'boost-biz-pro' ),
		'service_title'					=> esc_html__( 'Amazing landing page for your startup', 'boost-biz-pro' ),
		'service_btn_title'				=> esc_html__( 'View All Services', 'boost-biz-pro' ),
		'service_image_type'			=>'icon',

		// Portfolio
		'portfolio_section_enable'		=> true,
		'portfolio_content_type'		=> 'category',
		'portfolio_autoplay_enable'		=> false,
		'portfolio_count'				=> 4,
		'portfolio_sub_title'			=> esc_html__( 'Our Portfolio', 'boost-biz-pro' ),
		'portfolio_title'				=> esc_html__( 'Start browsing our latest projects', 'boost-biz-pro' ),
		'portfolio_btn_title'			=> esc_html__( 'View All Projects', 'boost-biz-pro' ),

		// Interest
		'interest_section_enable'		=> true,
		'interest_count'				=> 8,
		'interest_autoplay_enable'		=> false,
		'interest_sub_title'			=> esc_html__( 'My Interest', 'boost-biz-pro' ),
		'interest_title'				=> esc_html__( 'My Contribution to this World', 'boost-biz-pro' ),
		'interest_btn_title'			=> esc_html__( 'Read Full Article', 'boost-biz-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,


		// team
		'team_section_enable'	=> true,
		'team_title'			=> esc_html__( 'Our Teams', 'boost-biz-pro' ),
		'team_content_type'		=> 'category',
		'team_count'			=> 4,

		// About
		'client_section_enable'			=> true,
		'client_content_type'			=> 'page',
		'client_btn_title'				=> esc_html__( 'Check Our Partner Program', 'boost-biz-pro' ),
		'client_description'			=> esc_html__( 'With the help of our profile settings. you can find your target audience and engage with them without having to do everything manally. Simply play with our filters and let our AI take care of rest.', 'boost-biz-pro' ),
		'client_sub_title'				=> esc_html__( 'My Clients', 'boost-biz-pro' ),
		'client_title'					=> esc_html__( 'You are in hand of good company', 'boost-biz-pro' ),
		'client_logo_count'				=>6,
		'client_logo_content_type'		=>'category',

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_column'					=>'col-3',
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'My latest articles & resources', 'boost-biz-pro' ),
		'blog_sub_title'				=> esc_html__( 'My Blog', 'boost-biz-pro' ),
		'blog_readmore_title'			=> esc_html__( 'Learn More', 'boost-biz-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'boost-biz-pro' ),

		//COUNTER
		'counter_section_enable'	=> true,
		'counter_image'				=> get_template_directory_uri() .'/assets/uploads/medical-counter.jpg',
		'counter_count'				=> 4,

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_sub_title'					=> esc_html__( 'Contac Me', 'boost-biz-pro' ),
		'cta_title'						=> esc_html__( 'Start growing with me today!!', 'boost-biz-pro' ),
		'cta_btn_title'					=> esc_html__( 'Get Started', 'boost-biz-pro' ),
		'cta_description'				=> esc_html__( 'Kickstart your 21 -day free trial now. No credit card required. Switch to Free plan after trial.', 'boost-biz-pro' ),
	);

	$output = apply_filters( 'boost_biz_pro_default_theme_options', $boost_biz_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}