<?php
/**
 * Client Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Client section
$wp_customize->add_section( 'boost_biz_pro_client_section', array(
	'title'             => esc_html__( 'Client Section','boost-biz-pro' ),
	'description'       => esc_html__( 'Client Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_enable',
) );

// Client content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_section_enable]', array(
	'default'			=> 	$options['client_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[client_section_enable]', array(
	'label'             => esc_html__( 'Client Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_client_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// Client content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_content_type]', array(
	'default'          	=> $options['client_content_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_client_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'boost-biz-pro' ),
		'post' 		=> esc_html__( 'Post', 'boost-biz-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'boost-biz-pro' ),
	),
) );

// Client btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_sub_title]', array(
	'default'			=> 	$options['client_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_sub_title]', array(
	'label'           	=> sprintf( esc_html__( 'Sub Title', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[client_sub_title]', array(
		'selector'            => '#our-clients .section-header p',
		'settings'            => 'boost_biz_pro_theme_options[client_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_client_sub_title_partial',
    ) );
}

// client pages drop down chooser control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_content_page]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_page',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[client_content_page]', array(
	'label'             => sprintf( esc_html__( 'Select Page', 'boost-biz-pro' ) ),
	'section'           => 'boost_biz_pro_client_section',
	'choices'			=> boost_biz_pro_page_choices(),
	'active_callback'	=> 'boost_biz_pro_is_client_section_content_page_enable',
) ) );

// client posts drop down chooser control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_content_post]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_page',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[client_content_post]', array(
	'label'             => sprintf( esc_html__( 'Select Post', 'boost-biz-pro' ) ),
	'section'           => 'boost_biz_pro_client_section',
	'choices'			=> boost_biz_pro_post_choices(),
	'active_callback'	=> 'boost_biz_pro_is_client_section_content_post_enable',
) ) );

// client title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> 	$options['client_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_title]', array(
	'label'           	=> sprintf( esc_html__( 'Title', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[client_title]', array(
		'selector'            => '#our-clients .section-header h2',
		'settings'            => 'boost_biz_pro_theme_options[client_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_client_title_partial',
    ) );
}

// client description setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> 	$options['client_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_description]', array(
	'label'           	=> sprintf( esc_html__( 'Description', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[client_description]', array(
		'selector'            => '#our-clients .section-content',
		'settings'            => 'boost_biz_pro_theme_options[client_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_client_description_partial',
    ) );
}


// client position setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_link]', array(
	'label'           	=> sprintf( esc_html__( 'URL Link', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_content_custom_enable',
	'type'				=> 'url',
) );

// Client btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['client_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[client_btn_title]', array(
		'selector'            => '#our-clients .read-more a',
		'settings'            => 'boost_biz_pro_theme_options[client_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_client_btn_title_partial',
    ) );
}

// client hr setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Customize_Horizontal_Line( $wp_customize, 'boost_biz_pro_theme_options[client_hr]',
		array(
			'section'         => 'boost_biz_pro_client_section',
			'active_callback' => 'boost_biz_pro_is_client_section_enable',
			'type'			  => 'hr'
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_count]', array(
	'default'          	=> $options['client_logo_count'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_number_range',
	'validate_callback' => 'boost_biz_pro_validate_client_logo_count',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_logo_count]', array(
	'label'             => esc_html__( 'Number of Clients', 'boost-biz-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_client_section',
	'active_callback'   => 'boost_biz_pro_is_client_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Client content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_content_type]', array(
	'default'          	=> $options['client_logo_content_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_logo_content_type]', array(
	'label'             => esc_html__( 'Client logo Content Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_client_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_client_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'boost-biz-pro' ),
		'post' 		=> esc_html__( 'Post', 'boost-biz-pro' ),
		'category'	=> esc_html__( 'Category', 'boost-biz-pro'),
		'custom' 	=> esc_html__( 'Custom', 'boost-biz-pro' ),
	),
) );

for ( $i = 1; $i <= $options['client_logo_count']; $i++ ) :

	// client_logo pages drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_content_page_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[client_logo_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_client_section',
		'choices'			=> boost_biz_pro_page_choices(),
		'active_callback'	=> 'boost_biz_pro_is_client_logo_section_content_page_enable',
	) ) );

	// client_logo posts drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_content_post_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[client_logo_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_client_section',
		'choices'			=> boost_biz_pro_post_choices(),
		'active_callback'	=> 'boost_biz_pro_is_client_logo_section_content_post_enable',
	) ) );

	// client_logo image setting and control.
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_image_' . $i . ']', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'boost_biz_pro_theme_options[client_logo_image_' . $i . ']',
		array(
		'label'       		=> sprintf( esc_html__( 'Select logo %d', 'boost-biz-pro' ), $i ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'boost-biz-pro' ), 150, 50 ),
		'section'     		=> 'boost_biz_pro_client_section',
		'active_callback'	=> 'boost_biz_pro_is_client_logo_section_content_custom_enable',
) ) );

// Client btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_alt_text_' . $i .']', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_logo_alt_text_' . $i .']', array(
	'label'           	=> sprintf( esc_html__( 'logo Alt Text %d', 'boost-biz-pro' ), $i ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_logo_section_content_custom_enable',
	'type'				=> 'text',
) );

// client position setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[client_logo_link_' . $i . ']', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[client_logo_link_' . $i . ']', array(
	'label'           	=> sprintf( esc_html__( 'Logo URL Link %d', 'boost-biz-pro' ), $i ),
	'section'        	=> 'boost_biz_pro_client_section',
	'active_callback' 	=> 'boost_biz_pro_is_client_logo_section_content_custom_enable',
	'type'				=> 'url',
) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'boost_biz_pro_theme_options[client_logo_content_category]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Taxonomies_Control( $wp_customize,'boost_biz_pro_theme_options[client_logo_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'boost-biz-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_client_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'boost_biz_pro_is_client_logo_section_content_category_enable'
) ) );

