<?php
/**
 * Counter Section options
 * 
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'boost_biz_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','boost-biz-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
	'active_callback' 	=> 'boost_biz_pro_is_counter_section_enable',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new boost_biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_counter_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'boost_biz_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_image',
	'default'			=> $options['counter_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'boost_biz_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'boost-biz-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'boost-biz-pro' ), 1350, 385 ),
		'section'     		=> 'boost_biz_pro_counter_section',
		'active_callback'	=> 'boost_biz_pro_is_counter_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_number_range',
	'validate_callback' => 'boost_biz_pro_validate_counter_count',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'boost-biz-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_counter_section',
	'active_callback'   => 'boost_biz_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 4,
		'style' => 'width: 50%;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter title setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'boost_biz_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'boost-biz-pro' ), $i ),
		'section'        	=> 'boost_biz_pro_counter_section',
		'active_callback' 	=> 'boost_biz_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'boost_biz_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'boost-biz-pro' ), $i ),
		'section'        	=> 'boost_biz_pro_counter_section',
		'active_callback' 	=> 'boost_biz_pro_is_counter_section_enable',
        'type'				=> 'text',
        'input_attrs'		=> array(
            'style' => 'width: 50%;'
            ),
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new boost_biz_Pro_Customize_Horizontal_Line( $wp_customize, 'boost_biz_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'boost_biz_pro_counter_section',
			'active_callback' => 'boost_biz_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;



