<?php
/**
 * My Interest Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'boost_biz_pro_interest_section', array(
	'title'             => esc_html__( 'Interest Section','boost-biz-pro' ),
	'description'       => esc_html__( 'My Interest Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
	'active_callback' 	=> 'boost_biz_pro_is_interest_section_enable',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_section_enable]', array(
	'default'			=> 	$options['interest_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[interest_section_enable]', array(
	'label'             => esc_html__( 'My Interest Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_interest_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// Featured sub title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['interest_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[interest_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_interest_section',
	'active_callback' 	=> 'boost_biz_pro_is_interest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[interest_sub_title]', array(
		'selector'            => '#our-contribution .section-header p',
		'settings'            => 'boost_biz_pro_theme_options[interest_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_interest_sub_title_partial',
    ) );
}

// Featured title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['interest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[interest_title]', array(
	'label'           	=> esc_html__( 'Title', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_interest_section',
	'active_callback' 	=> 'boost_biz_pro_is_interest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[interest_title]', array(
		'selector'            => '#our-contribution .section-header h2',
		'settings'            => 'boost_biz_pro_theme_options[interest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_interest_title_partial',
    ) );
}

// Interest content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_autoplay_enable]', array(
	'default'			=> 	$options['interest_autoplay_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[interest_autoplay_enable]', array(
	'label'             => esc_html__( 'Interest Autoplay Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_interest_section',
	'active_callback'   => 'boost_biz_pro_is_interest_section_enable',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_count]', array(
	'default'          	=> $options['interest_count'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_number_range',
	'validate_callback' => 'boost_biz_pro_validate_interest_count',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[interest_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'boost-biz-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_interest_section',
	'active_callback'   => 'boost_biz_pro_is_interest_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// interest posts drop down chooser control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_categories]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Multiple_Chooser( $wp_customize, 'boost_biz_pro_theme_options[interest_categories]', array(
	'label'             => esc_html__( 'Select Multiple Categories', 'boost-biz-pro' ),
	'type'           	=> 'dropdown_multiple_chooser',
	'choices'			=> 	boost_biz_pro_category_choices(),
	'section'           => 'boost_biz_pro_interest_section',
	'active_callback'	=> 'boost_biz_pro_is_interest_section_enable',
) ) );

// Button Label setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[interest_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['interest_btn_title'],
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[interest_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_interest_section',
	'active_callback' 	=> 'boost_biz_pro_is_interest_section_enable',
	'type'				=> 'text',
) );