<?php
/**
 * Introduction Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Introduction section
$wp_customize->add_section( 'boost_biz_pro_introduction_section', array(
	'title'             => esc_html__( 'Introduction','boost-biz-pro' ),
	'description'       => esc_html__( 'Introduction Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
    'active_callback' 	=> 'boost_biz_pro_is_introduction_section_enable',
) );

// Introduction content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_section_enable]', array(
	'default'			=> 	$options['introduction_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[introduction_section_enable]', array(
	'label'             => esc_html__( 'Introduction Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_introduction_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// About btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_sub_title]', array(
	'default'			=> 	$options['introduction_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[introduction_sub_title]', array(
	'label'           	=> sprintf( esc_html__( 'Sub Title', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_introduction_section',
	'active_callback' 	=> 'boost_biz_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[introduction_sub_title]', array(
		'selector'            => '#blog-introduction div.entry-meta ul.post-categories li',
		'settings'            => 'boost_biz_pro_theme_options[introduction_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_introduction_sub_title_partial',
    ) );
}
// Introduction content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_content_type]', array(
	'default'          	=> $options['introduction_content_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[introduction_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_introduction_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_introduction_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'boost-biz-pro' ),
		'page' 		=> esc_html__( 'Page', 'boost-biz-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'boost-biz-pro' ),
	),
) );


// Introduction pages drop down chooser control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_content_page]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_page',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[introduction_content_page]', array(
	'label'             => sprintf( esc_html__( 'Select Page', 'boost-biz-pro' ) ),
	'section'           => 'boost_biz_pro_introduction_section',
	'choices'			=> boost_biz_pro_page_choices(),
	'active_callback'	=> 'boost_biz_pro_is_introduction_section_content_page_enable',
) ) );

// Introduction posts drop down chooser control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_content_post]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_page',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[introduction_content_post]', array(
	'label'             => sprintf( esc_html__( 'Select Post', 'boost-biz-pro' ) ),
	'section'           => 'boost_biz_pro_introduction_section',
	'choices'			=> boost_biz_pro_post_choices(),
	'active_callback'	=> 'boost_biz_pro_is_introduction_section_content_post_enable',
) ) );

// Introduction title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> 	$options['introduction_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[introduction_title]', array(
	'label'           	=> sprintf( esc_html__( 'Title', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_introduction_section',
	'active_callback' 	=> 'boost_biz_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[introduction_title]', array(
		'selector'            => '#blog-introduction .entry-container h2 a',
		'settings'            => 'boost_biz_pro_theme_options[introduction_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_introduction_title_partial',
    ) );
}


// Introduction image setting and control.
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_image]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'boost_biz_pro_theme_options[introduction_image]',
		array(
		'label'       		=> sprintf( esc_html__( 'Image', 'boost-biz-pro' ) ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'boost-biz-pro' ), 600, 600 ),
		'section'     		=> 'boost_biz_pro_introduction_section',
		'active_callback'	=> 'boost_biz_pro_is_introduction_section_content_custom_enable',
) ) );

// Introduction btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['introduction_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[introduction_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_introduction_section',
	'active_callback' 	=> 'boost_biz_pro_is_introduction_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[introduction_btn_title]', array(
		'selector'            => '#blog-introduction .entry-container .post-read-more a',
		'settings'            => 'boost_biz_pro_theme_options[introduction_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_introduction_btn_title_partial',
    ) );
}

// Introduction position setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[introduction_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[introduction_link]', array(
	'label'           	=> sprintf( esc_html__( 'URL Link', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_introduction_section',
	'active_callback' 	=> 'boost_biz_pro_is_introduction_section_content_custom_enable',
	'type'				=> 'url',
) );