<?php
/**
 * Portfolio Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'boost_biz_pro_portfolio_section', array(
	'title'             => esc_html__( 'Portfolio Section','boost-biz-pro' ),
	'description'       => esc_html__( 'Portfolio Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
	'active_callback' 	=> 'boost_biz_pro_is_portfolio_section_enable',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_section_enable]', array(
	'default'			=> 	$options['portfolio_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[portfolio_section_enable]', array(
	'label'             => esc_html__( 'Portfolio Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_portfolio_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// Featured sub title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[portfolio_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_portfolio_section',
	'active_callback' 	=> 'boost_biz_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[portfolio_sub_title]', array(
		'selector'            => '#our-portfolio .section-header-wrapper .section-header p',
		'settings'            => 'boost_biz_pro_theme_options[portfolio_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_portfolio_sub_title_partial',
    ) );
}

// Featured title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[portfolio_title]', array(
	'label'           	=> esc_html__( 'Title', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_portfolio_section',
	'active_callback' 	=> 'boost_biz_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[portfolio_title]', array(
		'selector'            => '#our-portfolio .section-header-wrapper .section-header h2',
		'settings'            => 'boost_biz_pro_theme_options[portfolio_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_portfolio_title_partial',
    ) );
}

// Portfolio content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_autoplay_enable]', array(
	'default'			=> 	$options['portfolio_autoplay_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[portfolio_autoplay_enable]', array(
	'label'             => esc_html__( 'Portfolio Autoplay Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_portfolio_section',
	'active_callback'   => 'boost_biz_pro_is_portfolio_section_enable',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_count]', array(
	'default'          	=> $options['portfolio_count'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_number_range',
	'validate_callback' => 'boost_biz_pro_validate_portfolio_count',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[portfolio_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'boost-biz-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_portfolio_section',
	'active_callback'   => 'boost_biz_pro_is_portfolio_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_content_type]', array(
	'default'          	=> $options['portfolio_content_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[portfolio_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'boost-biz-pro' ),
		'post' 		=> esc_html__( 'Post', 'boost-biz-pro' ),
		'category' 	=> esc_html__( 'Category', 'boost-biz-pro' ),
	),
) );

for ( $i = 1; $i <= $options['portfolio_count']; $i++ ) :
	// portfolio pages drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_portfolio_section',
		'choices'			=> boost_biz_pro_page_choices(),
		'active_callback'	=> 'boost_biz_pro_is_portfolio_section_content_page_enable',
	) ) );

	// portfolio posts drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_content_post_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[portfolio_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_portfolio_section',
		'choices'			=> boost_biz_pro_post_choices(),
		'active_callback'	=> 'boost_biz_pro_is_portfolio_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'boost_biz_pro_theme_options[portfolio_content_category]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Taxonomies_Control( $wp_customize,'boost_biz_pro_theme_options[portfolio_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'boost-biz-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_portfolio_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'boost_biz_pro_is_portfolio_section_content_category_enable'
) ) );


// Featured btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[portfolio_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_portfolio_section',
	'active_callback' 	=> 'boost_biz_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[portfolio_btn_title]', array(
		'selector'            => '#our-portfolio .wrapper .read-more a',
		'settings'            => 'boost_biz_pro_theme_options[portfolio_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_portfolio_btn_title_partial',
    ) );
}

// Featured btn url setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[portfolio_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[portfolio_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_portfolio_section',
	'active_callback' 	=> 'boost_biz_pro_is_portfolio_section_enable',
	'type'				=> 'url',
) );
