<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'boost_biz_pro_service_section', array(
	'title'             => esc_html__( 'Services','boost-biz-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_service_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// service sub title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_sub_title]', array(
	'default'			=> 	$options['service_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_sub_title]', array(
	'label'           	=> sprintf( esc_html__( 'Sub Title', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_service_section',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[service_sub_title]', array(
		'selector'            => '#our-services .section-header p',
		'settings'            => 'boost_biz_pro_theme_options[service_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_service_sub_title_partial',
    ) );
}

// Service title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_title]', array(
	'default'			=> 	$options['service_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_title]', array(
	'label'           	=> sprintf( esc_html__( 'Section Title', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_service_section',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[service_title]', array(
		'selector'            => '#our-services .section-header h2',
		'settings'            => 'boost_biz_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_service_title_partial',
    ) );
}

// service content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_column]', array(
	'default'          	=> $options['service_column'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_column]', array(
	'label'             => esc_html__( 'Column Layout', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'boost-biz-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'boost-biz-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_number_range',
	'validate_callback' => 'boost_biz_pro_validate_service_count',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Services', 'boost-biz-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_service_section',
	'active_callback'   => 'boost_biz_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'boost-biz-pro' ),
		'post' 		=> esc_html__( 'Post', 'boost-biz-pro' ),
		'category' 	=> esc_html__( 'Category', 'boost-biz-pro' ),
	),
) );

// Service image type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_image_type]', array(
	'default'          	=> $options['service_image_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_image_type]', array(
	'label'             => esc_html__( 'Image Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'choices'			=> array( 
		'image' 		=> esc_html__( 'Feature Image', 'boost-biz-pro' ),
		'icon' 			=> esc_html__( 'Icon', 'boost-biz-pro' ),
	),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Icon_Picker( $wp_customize, 'boost_biz_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_service_section',
		'active_callback'	=> 'boost_biz_pro_is_service_section_image_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_service_section',
		'choices'			=> boost_biz_pro_page_choices(),
		'active_callback'	=> 'boost_biz_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_service_section',
		'choices'			=> boost_biz_pro_post_choices(),
		'active_callback'	=> 'boost_biz_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Customize_Horizontal_Line( $wp_customize, 'boost_biz_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'boost_biz_pro_service_section',
			'active_callback' => 'boost_biz_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'boost_biz_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Taxonomies_Control( $wp_customize,'boost_biz_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'boost-biz-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'boost_biz_pro_is_service_section_content_category_enable'
) ) );

// About btn title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_service_section',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[service_btn_title]', array(
		'selector'            => '#our-services .read-more a',
		'settings'            => 'boost_biz_pro_theme_options[service_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_service_btn_title_partial',
    ) );
}

// service bt link setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[service_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[service_link]', array(
	'label'           	=> sprintf( esc_html__( 'URL Link', 'boost-biz-pro' ) ),
	'section'        	=> 'boost_biz_pro_service_section',
	'active_callback' 	=> 'boost_biz_pro_is_service_section_enable',
	'type'				=> 'url',
) );
