<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'boost_biz_pro_team_section', array(
	'title'             => esc_html__( 'Team','boost-biz-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
    'active_callback' 	=> 'boost_biz_pro_is_team_section_enable',
) );

// Team content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_team_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// team title setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_team_section',
	'active_callback' 	=> 'boost_biz_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[team_title]', array(
		'selector'            => '#medical-team .section-header h2',
		'settings'            => 'boost_biz_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_team_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_number_range',
	'validate_callback' => 'boost_biz_pro_validate_team_count',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Team', 'boost-biz-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_team_section',
	'active_callback'   => 'boost_biz_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Team content type control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_select',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'boost_biz_pro_is_team_section_enable',
	'choices'			=> array( 
		'category' 	=> esc_html__( 'Category', 'boost-biz-pro' ),
		'page' 		=> esc_html__( 'Page', 'boost-biz-pro' ),
		'post' 		=> esc_html__( 'Post', 'boost-biz-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'boost_biz_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'boost_biz_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Taxonomies_Control( $wp_customize,'boost_biz_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'boost-biz-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'boost_biz_pro_is_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :
	// Team pages drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_team_section',
		'choices'			=> boost_biz_pro_page_choices(),
		'active_callback'	=> 'boost_biz_pro_is_team_section_content_page_enable',
	) ) );

	// Team posts drop down chooser control and setting
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'boost_biz_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Dropdown_Chooser( $wp_customize, 'boost_biz_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'boost-biz-pro' ), $i ),
		'section'           => 'boost_biz_pro_team_section',
		'choices'			=> boost_biz_pro_post_choices(),
		'active_callback'	=> 'boost_biz_pro_is_team_section_content_post_enable',
	) ) );

	// Team position setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'boost_biz_pro_theme_options[team_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'boost-biz-pro' ), $i ),
		'section'        	=> 'boost_biz_pro_team_section',
		'active_callback' 	=> 'boost_biz_pro_is_team_section_enable',
		'type'				=> 'text',
	) );


	// Team hr setting and control
	$wp_customize->add_setting( 'boost_biz_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Boost_Biz_Pro_Customize_Horizontal_Line( $wp_customize, 'boost_biz_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'boost_biz_pro_team_section',
			'active_callback' => 'boost_biz_pro_is_team_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;
