<?php
/**
 * Topbar Section options
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */

// Add Topbar section
$wp_customize->add_section( 'boost_biz_pro_topbar_section', array(
	'title'             => esc_html__( 'Topbar','boost-biz-pro' ),
	'description'       => esc_html__( 'Topbar Section options.', 'boost-biz-pro' ),
	'panel'             => 'boost_biz_pro_front_page_panel',
) );

// Topbar content enable control and setting
$wp_customize->add_setting( 'boost_biz_pro_theme_options[topbar_section_enable]', array(
	'default'			=> 	$options['topbar_section_enable'],
	'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[topbar_section_enable]', array(
	'label'             => esc_html__( 'Topbar Section Enable', 'boost-biz-pro' ),
	'section'           => 'boost_biz_pro_topbar_section',
	'on_off_label' 		=> boost_biz_pro_switch_options(),
) ) );

// top bar menu visible
$wp_customize->add_setting( 'boost_biz_pro_theme_options[topbar_social_enable]',
	array(
		'default'       	=> $options['topbar_social_enable'],
		'sanitize_callback' => 'boost_biz_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Boost_Biz_Pro_Switch_Control( $wp_customize, 'boost_biz_pro_theme_options[topbar_social_enable]',
    array(
		'label'      		=> esc_html__( 'Display Social Menu', 'boost-biz-pro' ),
		'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show topbar menu.', 'boost-biz-pro' ), esc_html__( 'Click Here', 'boost-biz-pro' ), esc_html__( 'to create menu', 'boost-biz-pro' ) ),
		'section'    		=> 'boost_biz_pro_topbar_section',
		'active_callback'	=> 'boost_biz_pro_is_topbar_section_enable',
		'on_off_label' 		=> boost_biz_pro_switch_options(),
    )
) );

// topbar email setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[topbar_email]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_email'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[topbar_email]', array(
	'label'           	=> esc_html__( 'Email ID', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_topbar_section',
	'active_callback' 	=> 'boost_biz_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[topbar_email]', array(
		'selector'            => '#top-navigation .widget_contact_info .topbar-email a',
		'settings'            => 'boost_biz_pro_theme_options[topbar_email]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_topbar_email_partial',
    ) );
}

// topbar phone setting and control
$wp_customize->add_setting( 'boost_biz_pro_theme_options[topbar_phone]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_phone'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'boost_biz_pro_theme_options[topbar_phone]', array(
	'label'           	=> esc_html__( 'Phone No.', 'boost-biz-pro' ),
	'section'        	=> 'boost_biz_pro_topbar_section',
	'active_callback' 	=> 'boost_biz_pro_is_topbar_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'boost_biz_pro_theme_options[topbar_phone]', array(
		'selector'            => '#top-navigation .widget_contact_info .topbar-phone a',
		'settings'            => 'boost_biz_pro_theme_options[topbar_phone]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'boost_biz_pro_topbar_phone_partial',
    ) );
}