<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_about_section() {
    	$options = boost_biz_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'boost_biz_pro_section_status', true, 'about_section_enable' );

        if($options['home_layout'] == 'second-design') $about_enable = false;

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'boost_biz_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        switch ( $options['home_layout'] ) {
            case 'default-design':
                // Render about section now.
                boost_biz_pro_render_about_section( $section_details );
                break;
            
            case 'third-design':
                // Render about section now.
                boost_biz_pro_render_about_medical_section( $section_details );
                break;
            default:
                boost_biz_pro_render_about_section( $section_details );
        }

    }
endif;

if ( ! function_exists( 'boost_biz_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Boost Biz Pro 1.0.0
    * @param array $input about section details.
    */
    function boost_biz_pro_get_about_section_details( $input ) {
        $options = boost_biz_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        $about_count = ! empty( $options['about_count'] ) ? $options['about_count'] : 1;

        
        $content = array();
        switch ( $about_content_type ) {
    
            case 'page':
                $page_ids = array();
                for ( $i = 1; $i <= $about_count; $i++ ) {
                    if ( ! empty( $options['about_content_page_' . $i] ) )
                        $page_ids[] = $options['about_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $about_count ),
                    );                    
            break;

            case 'post':
                $post_ids = array();
                for ( $i = 1; $i <= $about_count; $i++ ) {
                    if ( ! empty( $options['about_content_post_' . $i] ) )
                        $post_ids[] = $options['about_content_post_' . $i];
                }
                $args = array(
                    'post_type'             => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'        => absint( $about_count ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['about_content_category'] ) ? $options['about_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $about_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

                // Push to the main array.
                array_push( $content, $custom );
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['sub_title'] = ! empty( $options['about_sub_title'] ) ? $options['about_sub_title'] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = boost_biz_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'boost_biz_pro_filter_about_section_details', 'boost_biz_pro_get_about_section_details' );


if ( ! function_exists( 'boost_biz_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_about_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Learn More', 'boost-biz-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="about-us" class="relative page-section">
                <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <header class="entry-header">
                                <?php if ( ! empty( $content['sub_title'] ) ) : ?>
                                    <p><?php echo esc_html( $content['sub_title'] ); ?></p>
                                <?php endif; ?>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                 <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                    <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                    <?php echo esc_html( $readmore ); ?>
                                </a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->

    <?php }
endif;

if ( ! function_exists( 'boost_biz_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_about_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Learn More', 'boost-biz-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="about-us" class="relative page-section">
                <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <header class="entry-header">
                                <?php if ( ! empty( $content['sub_title'] ) ) : ?>
                                    <p><?php echo esc_html( $content['sub_title'] ); ?></p>
                                <?php endif; ?>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                 <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                    <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                    <?php echo esc_html( $readmore ); ?>
                                </a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->

    <?php }
endif;

if ( ! function_exists( 'boost_biz_pro_render_about_medical_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_about_medical_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : esc_html__( 'Learn More', 'boost-biz-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="medical-about-us" class="relative page-section">
                <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                 <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                            </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->

    <?php }
endif;
