<?php
/**
 * Client section
 *
 * This is the template for the content of client section
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_client_section' ) ) :
    /**
    * Add client section
    *
    *@since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_client_section() {
    	$options = boost_biz_pro_get_theme_options();
        // Check if client is enabled on frontpage
        $client_enable = apply_filters( 'boost_biz_pro_section_status', true, 'client_section_enable' );

        if($options['home_layout'] != 'default-design') $client_enable = false;

        if ( true !== $client_enable ) {
            return false;
        }
        // Get client section details
        $section_details = array();
        $section_details = apply_filters( 'boost_biz_pro_filter_client_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render client section now.
        boost_biz_pro_render_client_section( $section_details );
    }
endif;

if ( ! function_exists( 'boost_biz_pro_get_client_section_details' ) ) :
    /**
    * client section details.
    *
    * @since Boost Biz Pro 1.0.0
    * @param array $input client section details.
    */
    function boost_biz_pro_get_client_section_details( $input ) {
        $options = boost_biz_pro_get_theme_options();

        // Content type.
        $client_content_type  = $options['client_content_type'];
        $client_logo_content_type  = $options['client_logo_content_type'];
        $client_logo_count = ! empty( $options['client_logo_count'] ) ? $options['client_logo_count'] : 6;
        
        $content = array();
        $content['intro'] = array();

        switch ( $client_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['client_content_page'] ) ? $options['client_content_page'] : '';
                
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['client_content_post'] ) ? $options['client_content_post'] : '';

                $args = array(
                    'post_type'             => 'post',
                    'p'                     => $post_id,
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

             case 'custom':
                $custom['title']        = ! empty( $options['client_title'] ) ? $options['client_title'] : '';
                $custom['excerpt']      = ! empty( $options['client_description'] ) ? $options['client_description'] : '';
                $custom['image']        = ! empty( $options['client_image'] ) ? $options['client_image'] : '';
                $custom['url']          = ! empty( $options['client_link'] ) ? $options['client_link'] : '';
                $custom['sub_title']     = ! empty( $options['client_sub_title'] ) ? $options['client_sub_title'] : '';


                // Push to the main array.
                array_push( $content['intro'], $custom );
            break;

            default:
            break;
        }

        if ( 'custom' !== $client_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['sub_title'] = ! empty( $options['client_sub_title'] ) ? $options['client_sub_title'] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = boost_biz_pro_trim_content( 25 );

                    // Push to the main array.
                    array_push( $content['intro'], $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        }

        $content['clients'] = array();

        switch ( $client_logo_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $client_logo_count; $i++ ) {
                    if ( ! empty( $options['client_logo_content_page_' . $i] ) ) :
                        $page_ids[] = $options['client_logo_content_page_' . $i];
                    endif;
                }
                
                $args1 = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $client_logo_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $client_logo_count; $i++ ) {
                    if ( ! empty( $options['client_logo_content_post_' . $i] ) ) :
                        $post_ids[] = $options['client_logo_content_post_' . $i];
                    endif;
                }
                
                $args1 = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $client_logo_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['client_logo_content_category'] ) ? $options['client_logo_content_category'] : '';
                $args1 = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $client_logo_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $client_logo_count; $i++ ) {
                    $custom['image']        = ! empty( $options['client_logo_image_' . $i] ) ? $options['client_logo_image_' . $i] : '';
                    $custom['url']          = ! empty( $options['client_logo_link_' . $i] ) ? $options['client_logo_link_' . $i] : '';
                    $custom['title']          = ! empty( $options['client_logo_alt_text_' . $i] ) ? $options['client_logo_alt_text_' . $i] : '';

                    // Push to the main array.
                    array_push( $content['clients'], $custom );
                }
            break;

            default:
            break;
        }

        if ( 'custom' !== $client_logo_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args1 );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $client_page_post['title']     = get_the_title();
                    $client_page_post['url']       = get_the_permalink();
                    $client_page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium' ) : '';

                    // Push to the main array.
                    array_push( $content['clients'], $client_page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// client section content details.
add_filter( 'boost_biz_pro_filter_client_section_details', 'boost_biz_pro_get_client_section_details' );


if ( ! function_exists( 'boost_biz_pro_render_client_section' ) ) :
  /**
   * Start client section
   *
   * @return string client content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_client_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $client_logo_content_type  = $options['client_logo_content_type'];
        $readmore = ! empty( $options['client_btn_title'] ) ? $options['client_btn_title'] : esc_html__( 'Learn More', 'boost-biz-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-clients" class="relative page-section">
                <div class="wrapper">
                    <div class="clear col-2">
                        <?php foreach ( $content_details['intro'] as $content ) : ?>
                            <div class="hentry">
                                <div class="section-header">
                                    <?php if ( ! empty( $content['sub_title'] ) ) : ?>
                                        <p class="section-subtitle"><?php echo esc_html( $content['sub_title'] ); ?></p>
                                    <?php endif; ?>
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                </div><!-- .section-header -->

                                <div class="section-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .section-content -->

                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                        <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                        <?php echo esc_html( $readmore ); ?>
                                    </a>
                                </div><!-- .read-more -->
                            </div><!-- .hentry -->
                        <?php endforeach; ?>

                        <div class="hentry partner-logo">
                            <?php foreach( $content_details['clients'] as $content ) : ?>
                                <a href="<?php echo esc_attr( $content['url'] ); ?>">
                                    <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                </a>
                            <?php endforeach; ?>
                            
                        </div><!-- .hentry -->
                    </div><!-- .col-2 -->
                </div><!-- .wrapper -->
            </div><!-- #our-clients -->

    <?php }
endif;
