<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 * 
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    * @since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_counter_section() {
        $options = boost_biz_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'boost_biz_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        boost_biz_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'boost_biz_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_counter_section() {
        $options = boost_biz_pro_get_theme_options();
        $image   = empty( $options['counter_image'] ) ? '' : $options['counter_image'] ;
        $counter_count   = empty( $options['counter_count'] ) ? '' : $options['counter_count'] ;
        $contents = array();
        for( $i= 1; $i <= $counter_count; $i++ ){
            $page_post['title']     = isset($options['counter_title_'.$i]) ? $options['counter_title_'.$i] : '';
            $page_post['number']    =  isset($options['counter_number_'.$i]) ? $options['counter_number_'.$i] : '';
            if(!empty($page_post['title']) && !empty($page_post['title'])){
                array_push( $contents, $page_post );
            }
        } 
        ?>

            <div id="medical-counter" class="relative page-section" style="background-image: url('<?php echo esc_html($image); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <div class="medical-section-content clear col-<?php echo esc_attr($counter_count); ?>">
                    <?php if(!empty($contents)) :
                        foreach($contents as $content) : ?>
                        <article>
                            <header class="entry-header">
                                <h3 class="counter-value"><?php echo esc_html($content['number']); ?></h3>
                                <div class="separator-line"></div>
                                <h2 class="entry-title"><?php echo esc_html($content['title']); ?></h2>
                            </header>
                        </article>
                        <?php endforeach;
                        endif; ?>
                    </div><!-- .medical-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #medical-counter -->
    <?php }
endif;
