<?php
/**
 * Interest Section
 *
 * This is the template for the content of interest section
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_interest_section' ) ) :
    /**
    * Add interest section
    *
    *@since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_interest_section() {
    	$options = boost_biz_pro_get_theme_options();
        // Check if interest is enabled on frontpage
        $interest_enable = apply_filters( 'boost_biz_pro_section_status', true, 'interest_section_enable' );

        if($options['home_layout'] != 'default-design'){
            $interest_enable = false;
        }
        if ( true !== $interest_enable ) {
            return false;
        }
        // Get interest section details
        $section_details = array();
        $section_details = apply_filters( 'boost_biz_pro_filter_interest_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render interest section now.
        boost_biz_pro_render_interest_section( $section_details );
    }
endif;

if ( ! function_exists( 'boost_biz_pro_get_interest_section_details' ) ) :
    /**
    * interest section details.
    *
    * @since Boost Biz Pro 1.0.0
    * @param array $input interest section details.
    */
    function boost_biz_pro_get_interest_section_details( $input ) {
        $options = boost_biz_pro_get_theme_options();

        // Content type.
        $interest_count = ! empty( $options['interest_count'] ) ? $options['interest_count'] : 8;
        
        $content = array();
        $cats = ! empty( $options['interest_categories'] ) ? $options['interest_categories'] : array();
        
        if ( empty( $cats ) )
            return;

        $args = array(
            'post_type'             => 'post',
            'posts_per_page'        => absint( $interest_count ),
            'category__in'          => $cats,
            'ignore_sticky_posts'   => true,
            ); 

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = boost_biz_pro_trim_content( 25 );
                    $page_post['author']    = boost_biz_pro_author();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';


                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// interest section content details.
add_filter( 'boost_biz_pro_filter_interest_section_details', 'boost_biz_pro_get_interest_section_details' );


if ( ! function_exists( 'boost_biz_pro_render_interest_section' ) ) :
  /**
   * Start interest section
   *
   * @return string interest content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_interest_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $cats = ! empty( $options['interest_categories'] ) ? $options['interest_categories'] : array();
        $readmore = ! empty( $options['interest_btn_title'] ) ? $options['interest_btn_title'] : '';
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-contribution" class="relative page-section">
                <div class="wrapper">
                    <?php if ( ! empty( $options['interest_title'] ) || ! empty( $options['interest_sub_title'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['interest_sub_title'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['interest_sub_title'] ); ?></p>
                            <?php endif; 

                            if ( ! empty( $options['interest_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['interest_title'] ); ?></h2>
                            <?php endif; ?>

                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <ul class="filter-tabs">
                        <li class="active"><a href="#" data-slug="all"><?php esc_html_e( 'All', 'boost-biz-pro' ); ?></a>
                        </li>
                        <?php foreach ( $cats as $cat ) : 
                            $category = get_category( $cat ); ?>
                            <li>
                                <a href="#" data-slug="<?php echo esc_attr( $category->slug ); ?>"><?php echo esc_html( $category->name ); ?></a>
                            </li>
                        <?php endforeach; ?>
                    </ul><!-- .tabs -->

                    <div class="filtering-posts" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":true, "autoplay": <?php echo $options['interest_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": true }'>
                        <?php foreach ( $content_details as $content ) : 
                            $post_category = get_the_category( $content['id'] );
                        ?>

                            <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail all <?php foreach ( $post_category as $cat ) { echo esc_attr($cat->slug) . ' '; } ?>">

                                <div class="featured-image" style="background-image:url(<?php echo esc_url( $content['image'] ); ?>)">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <div class="entry-meta">
                                        <?php boost_biz_pro_posted_on( $content['id'] ); ?> 
                                    </div><!-- .entry-meta -->

                                    <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                            <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span> 
                                            <?php echo esc_html( $readmore ); ?>
                                        </a>
                                    </div><!-- .read-more -->
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .filtering -->
                </div><!-- .wrapper -->
            </div><!-- #our-contribution -->








    <?php }
endif;