<?php
/**
 * introduction section
 *
 * This is the template for the content of introduction section
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_introduction_section' ) ) :
    /**
    * Add introduction section
    *
    *@since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_introduction_section() {
    	$options = boost_biz_pro_get_theme_options();
        // Check if introduction is enabled on frontpage
        $introduction_enable = apply_filters( 'boost_biz_pro_section_status', true, 'introduction_section_enable' );

        if($options['home_layout'] != 'second-design'){
            $introduction_enable = false;
        }

        if ( true !== $introduction_enable ) {
            return false;
        }
        // Get introduction section details
        $section_details = array();
        $section_details = apply_filters( 'boost_biz_pro_filter_introduction_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render introduction section now.
        boost_biz_pro_render_introduction_section( $section_details );
    }
endif;

if ( ! function_exists( 'boost_biz_pro_get_introduction_section_details' ) ) :
    /**
    * introduction section details.
    *
    * @since Boost Biz Pro 1.0.0
    * @param array $input introduction section details.
    */
    function boost_biz_pro_get_introduction_section_details( $input ) {
        $options = boost_biz_pro_get_theme_options();

        // Content type.
        $introduction_content_type  = $options['introduction_content_type'];
        
        $content = array();
        switch ( $introduction_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['introduction_content_page'] ) ? $options['introduction_content_page'] : '';
                $subtitle = array();
                
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['introduction_content_post'] ) ? $options['introduction_content_post'] : '';
                $subtitle = array();

                $args = array(
                    'post_type'             => 'post',
                    'p'                     => $post_id,
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

             case 'custom':
                $custom['title']        = ! empty( $options['introduction_title'] ) ? $options['introduction_title'] : '';
                $custom['image']        = ! empty( $options['introduction_image'] ) ? $options['introduction_image'] : '';
                $custom['url']          = ! empty( $options['introduction_link'] ) ? $options['introduction_link'] : '';
                $custom['introduction_sub_title']    = ! empty( $options['introduction_sub_title'] ) ? $options['introduction_sub_title'] : '';


                // Push to the main array.
                array_push( $content, $custom );
            break;

            default:
            break;
        }

        if ( 'custom' !== $introduction_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['introduction_sub_title']    = ! empty( $options['introduction_sub_title'] ) ? $options['introduction_sub_title'] : '';
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// introduction section content details.
add_filter( 'boost_biz_pro_filter_introduction_section_details', 'boost_biz_pro_get_introduction_section_details' );


if ( ! function_exists( 'boost_biz_pro_render_introduction_section' ) ) :
  /**
   * Start introduction section
   *
   * @return string introduction content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_introduction_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $readmore = ! empty( $options['introduction_btn_title'] ) ? $options['introduction_btn_title'] : esc_html__( 'Learn More', 'boost-biz-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 
        $content = $content_details[0]; ?>

        <div id="blog-introduction" class="relative page-section">
            <div class="wrapper">
                <article class="has-post-thumbnail">
                    <?php if ( ! empty( $content['image'] ) ) : ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                    <div class="entry-container">
                        <div class="entry-meta">
                            <span class="cat-links">
                                <ul class="post-categories">
                                <li><?php echo esc_html($content['introduction_sub_title'])?></li></ul>                    
                            </span><!-- .cat-links -->
                        </div><!-- .entry-meta -->

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                        <?php if(!empty($readmore)): ?>
                        <div class="post-read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $readmore ); ?><i class="fa fa-long-arrow-right"></i></a>
                        </div><!-- .post-read-more -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>
            </div><!-- .wrapper -->
        </div><!-- #blog-introduction -->

    <?php }
endif;
