<?php
/**
 * Portfolio Section
 *
 * This is the template for the content of portfolio section
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_portfolio_section' ) ) :
    /**
    * Add portfolio section
    *
    *@since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_portfolio_section() {
    	$options = boost_biz_pro_get_theme_options();
        // Check if portfolio is enabled on frontpage
        $portfolio_enable = apply_filters( 'boost_biz_pro_section_status', true, 'portfolio_section_enable' );

        if($options['home_layout'] != 'default-design') $portfolio_enable = false;

        if ( true !== $portfolio_enable ) {
            return false;
        }
        // Get portfolio section details
        $section_details = array();
        $section_details = apply_filters( 'boost_biz_pro_filter_portfolio_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render portfolio section now.
        boost_biz_pro_render_portfolio_section( $section_details );
    }
endif;

if ( ! function_exists( 'boost_biz_pro_get_portfolio_section_details' ) ) :
    /**
    * portfolio section details.
    *
    * @since Boost Biz Pro 1.0.0
    * @param array $input portfolio section details.
    */
    function boost_biz_pro_get_portfolio_section_details( $input ) {
        $options = boost_biz_pro_get_theme_options();

        // Content type.
        $portfolio_content_type  = $options['portfolio_content_type'];
        $portfolio_count = ! empty( $options['portfolio_count'] ) ? $options['portfolio_count'] : 4;
        
        $content = array();
        switch ( $portfolio_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $portfolio_count; $i++ ) {
                    if ( ! empty( $options['portfolio_content_page_' . $i] ) )
                        $page_ids[] = $options['portfolio_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $portfolio_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $portfolio_count; $i++ ) {
                    if ( ! empty( $options['portfolio_content_post_' . $i] ) )
                        $post_ids[] = $options['portfolio_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $portfolio_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['portfolio_content_category'] ) ? $options['portfolio_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $portfolio_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = boost_biz_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// portfolio section content details.
add_filter( 'boost_biz_pro_filter_portfolio_section_details', 'boost_biz_pro_get_portfolio_section_details' );


if ( ! function_exists( 'boost_biz_pro_render_portfolio_section' ) ) :
  /**
   * Start portfolio section
   *
   * @return string portfolio content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_portfolio_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        $portfolio_content_type  = $options['portfolio_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-portfolio" class="relative page-section">
            <div class="box"></div>
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <?php if ( ! empty( $options['portfolio_title'] ) || ! empty( $options['portfolio_sub_title'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['portfolio_sub_title'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['portfolio_sub_title'] ); ?></p>
                            <?php endif; 

                        if ( ! empty( $options['portfolio_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['portfolio_title'] ); ?></h2>
                        <?php endif; ?>

                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <?php if ( ! empty( $options['portfolio_btn_title'] ) && ! empty( $options['portfolio_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['portfolio_btn_url'] ); ?>" class="btn">
                            <?php echo esc_html( $options['portfolio_btn_title'] ); ?>
                        </a>
                    </div><!-- .read-more -->
                <?php endif; ?>
                </div><!-- .section-header-wrapper -->

                <div class="portfolio-slider modern-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo $options['portfolio_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": false }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( 'page' !== $portfolio_content_type ) : ?>
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                    </div><!-- .entry-meta -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                     <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .portfolio-slider -->

                <?php if ( ! empty( $options['portfolio_btn_title'] ) && ! empty( $options['portfolio_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['portfolio_btn_url'] ); ?>" class="btn">
                            <?php echo esc_html( $options['portfolio_btn_title'] ); ?>
                        </a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #our-portfolio -->

    <?php }
endif;