<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Boost Biz Pro
 * @since Boost Biz Pro 1.0.0
 */
if ( ! function_exists( 'boost_biz_pro_add_team_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Boost Biz Pro 1.0.0
    */
    function boost_biz_pro_add_team_section() {
    	$options = boost_biz_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $team_enable = apply_filters( 'boost_biz_pro_section_status', true, 'team_section_enable' );

        if ( true !== $team_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'boost_biz_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        boost_biz_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'boost_biz_pro_get_team_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Boost Biz Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function boost_biz_pro_get_team_section_details( $input ) {
        $options = boost_biz_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count = ! empty( $options['team_count'] ) ? $options['team_count'] : 3;
        
        $content = array();
        switch ( $team_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) ) :
                        $page_ids[] = $options['team_content_page_' . $i];
                        $position[] = ! empty( $options['team_position_' . $i] ) ? $options['team_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) ) :
                        $post_ids[] = $options['team_content_post_' . $i];
                        $position[] = ! empty( $options['team_position_' . $i] ) ? $options['team_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $team_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        $i = 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['position']  = ( 'category' !== $team_content_type && ! empty( $position[$i] ) ) ? $position[$i] : '';
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = boost_biz_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'boost_biz_pro_filter_team_section_details', 'boost_biz_pro_get_team_section_details' );


if ( ! function_exists( 'boost_biz_pro_render_team_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Boost Biz Pro 1.0.0
   *
   */
   function boost_biz_pro_render_team_section( $content_details = array() ) {
        $options = boost_biz_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="medical-team" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['team_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php foreach($content_details as $content) : ?>
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                             <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                    </h2>
                                        <?php if ( ! empty( $content['position'] ) ) : ?>
                                            <p class="position"><?php echo esc_html( $content['position'] ); ?></p>
                                        <?php endif; ?>
                                </header>
                            </div><!-- .entry-container -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #medical-team -->

    <?php }
endif;